@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
 # Copyright 2007-2009 Zuza Software Foundation
 #
@@ -18,55 +16,57 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""This module represents French language.
+"""This module represents the French language.
 
-For more information, see U{http://en.wikipedia.org/wiki/French_language}
+.. seealso:: http://en.wikipedia.org/wiki/French_language
 """
 
-from translate.lang import common
+
 import re
 
+from translate.lang import common
+
 
 def guillemets(text):
-
     def convertquotation(match):
         prefix = match.group(1)
         # Let's see that we didn't perhaps match an XML tag property like
         # <a href="something">
-        if prefix == u"=":
+        if prefix == "=":
             return match.group(0)
-        return u"%s«\u00a0%s\u00a0»" % (prefix, match.group(2)) #\u00a0 is NBSP
+        return f"{prefix}«\u00a0{match.group(2)}\u00a0»"  # \u00a0 is NBSP
 
     # Check that there is an even number of double quotes, otherwise it is
     # probably not safe to convert them.
-    if text.count(u'"') % 2 == 0:
+    if text.count('"') % 2 == 0:
         text = re.sub('(.|^)"([^"]+)"', convertquotation, text)
-    singlecount = text.count(u"'")
+    singlecount = text.count("'")
     if singlecount:
-        if singlecount == text.count(u'`'):
+        if singlecount == text.count("`"):
             text = re.sub("(.|^)`([^']+)'", convertquotation, text)
         elif singlecount % 2 == 0:
             text = re.sub("(.|^)'([^']+)'", convertquotation, text)
-    text = re.sub(u'(.|^)“([^”]+)”', convertquotation, text)
+    text = re.sub("(.|^)“([^”]+)”", convertquotation, text)
     return text
 
 
 class fr(common.Common):
     """This class represents French."""
 
-    validaccel = u"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ" + \
-                 u"1234567890" + \
-                 u"éÉ"
+    validaccel = (
+        "abcdefghijklmnopqrstuvwxyz" "ABCDEFGHIJKLMNOPQRSTUVWXYZ" "1234567890" "é" "É"
+    )
 
     # According to http://french.about.com/library/writing/bl-punctuation.htm,
     # in French, a space is required both before and after all two- (or more)
     # part punctuation marks and symbols, including : ; « » ! ? % $ # etc.
     puncdict = {}
-    for c in u":;!?#":
-        puncdict[c] = u"\u00a0%s" % c
+    for c in ":;!?#":
+        puncdict[c] = "\u00a0%s" % c
     # TODO: consider adding % and $, but think about the consequences of how
     # they could be part of variables
 
+    @classmethod
     def punctranslate(cls, text):
         """Implement some extra features for quotation marks.
 
@@ -74,9 +74,8 @@ class fr(common.Common):
             - % and $ are not touched yet for fear of variables
             - Double spaces might be introduced
         """
-        text = super(cls, cls).punctranslate(text)
+        text = super().punctranslate(text)
         # We might get problems where we got a space in URIs such as
         # http ://
-        text = text.replace(u"\u00a0://", "://")
+        text = text.replace("\u00a0://", "://")
         return guillemets(text)
-    punctranslate = classmethod(punctranslate)
