@@ -26,8 +26,18 @@ from translate.storage import base, html
 def test_guess_encoding():
     """Read an encoding header to guess the encoding correctly"""
     h = html.htmlfile()
-    assert h.guess_encoding(b'''<META HTTP-EQUIV="CONTENT-TYPE" CONTENT="text/html; charset=UTF-8">''') == "UTF-8"
-    assert h.guess_encoding(b'''<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN" "http://www.w3.org/TR/REC-html40/loose.dtd"><html><head><meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1"><!-- base href="http://home.online.no/~rut-aane/linux.html" --><link rel="shortcut icon" href="http://home.online.no/~rut-aane/peng16x16a.gif"><meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1"><meta name="Description" content="Linux newbie stuff and a little about Watching TV under Linux"><meta name="MSSmartTagsPreventParsing" content="TRUE"><meta name="GENERATOR" content="Mozilla/4.7 [en] (X11; I; Linux 2.2.5-15 i586) [Netscape]"><title>Some Linux for beginners</title><style type="text/css">''') == "iso-8859-1"
+    assert (
+        h.guess_encoding(
+            b"""<META HTTP-EQUIV="CONTENT-TYPE" CONTENT="text/html; charset=UTF-8">"""
+        )
+        == "UTF-8"
+    )
+    assert (
+        h.guess_encoding(
+            b"""<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN" "http://www.w3.org/TR/REC-html40/loose.dtd"><html><head><meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1"><!-- base href="http://home.online.no/~rut-aane/linux.html" --><link rel="shortcut icon" href="http://home.online.no/~rut-aane/peng16x16a.gif"><meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1"><meta name="Description" content="Linux newbie stuff and a little about Watching TV under Linux"><meta name="MSSmartTagsPreventParsing" content="TRUE"><meta name="GENERATOR" content="Mozilla/4.7 [en] (X11; I; Linux 2.2.5-15 i586) [Netscape]"><title>Some Linux for beginners</title><style type="text/css">"""
+        )
+        == "iso-8859-1"
+    )
 
 
 class TestHTMLParsing:
@@ -39,10 +49,14 @@ class TestHTMLParsing:
             self.h.parsestring("<h3><p>Some text<p></h3>")
         # First <tr> is not closed
         with raises(base.ParseError):
-            self.h.parsestring("<html><head></head><body><table><tr><th>Heading One</th><th>Heading Two</th><tr><td>One</td><td>Two</td></tr></table></body></html>")
+            self.h.parsestring(
+                "<html><head></head><body><table><tr><th>Heading One</th><th>Heading Two</th><tr><td>One</td><td>Two</td></tr></table></body></html>"
+            )
         # <tr> is not closed in <thead>
         with raises(base.ParseError):
-            self.h.parsestring("""<table summary="This is the summary"><caption>A caption</caption><thead><tr><th abbr="Head 1">Heading One</th><th>Heading Two</th></thead><tfoot><tr><td>Foot One</td><td>Foot Two</td></tr></tfoot><tbody><tr><td>One</td><td>Two</td></tr></tbody></table>""")
+            self.h.parsestring(
+                """<table summary="This is the summary"><caption>A caption</caption><thead><tr><th abbr="Head 1">Heading One</th><th>Heading Two</th></thead><tfoot><tr><td>Foot One</td><td>Foot Two</td></tr></tfoot><tbody><tr><td>One</td><td>Two</td></tr></tbody></table>"""
+            )
 
     def test_self_closing_tags(self):
         h = html.htmlfile()
@@ -55,7 +69,9 @@ class TestHTMLParsing:
         interpretted as tags
         """
         h = html.htmlfile()
-        store = h.parsestring("<p>We are here</p><script>Some </tag>like data<script></p>")
+        store = h.parsestring(
+            "<p>We are here</p><script>Some </tag>like data<script></p>"
+        )
         print(store.units[0].source)
         assert len(store.units) == 1
 
@@ -67,27 +83,56 @@ class TestHTMLExtraction:
     def strip_html(self, str):
         h = html.htmlfile()
         store = h.parsestring(str)
-        return "\n".join([u.source for u in store.units])
+        return "\n".join(u.source for u in store.units)
 
     def test_strip_html(self):
         assert self.strip_html("<p><a>Something</a></p>") == "Something"
-        assert self.strip_html("<p>You are <a>Something</a></p>") == "You are <a>Something</a>"
-        assert self.strip_html("<p><b>You</b> are <a>Something</a></p>") == "<b>You</b> are <a>Something</a>"
-        assert self.strip_html('<p><strong><font class="headingwhite">Projects</font></strong></p>') == "Projects"
-        assert self.strip_html("<p><strong>Something</strong> else.</p>") == "<strong>Something</strong> else."
-        assert self.strip_html("<h1><strong>Something</strong> else.</h1>") == "<strong>Something</strong> else."
-        assert self.strip_html('<h1 id="moral"><strong>We believe</strong> that the internet should be public, open and accessible.</h1>') == "<strong>We believe</strong> that the internet should be public, open and accessible."
-        assert self.strip_html('<h3><a href="http://www.firefox.com/" class="producttitle"><img src="../images/product-firefox-50.png" width="50" height="50" alt="" class="featured" style="display: block; margin-bottom: 30px;" /><strong>Firefox for Desktop</strong></a></h3>') == 'Firefox for Desktop'
+        assert (
+            self.strip_html("<p>You are <a>Something</a></p>")
+            == "You are <a>Something</a>"
+        )
+        assert (
+            self.strip_html("<p><b>You</b> are <a>Something</a></p>")
+            == "<b>You</b> are <a>Something</a>"
+        )
+        assert (
+            self.strip_html(
+                '<p><strong><font class="headingwhite">Projects</font></strong></p>'
+            )
+            == "Projects"
+        )
+        assert (
+            self.strip_html("<p><strong>Something</strong> else.</p>")
+            == "<strong>Something</strong> else."
+        )
+        assert (
+            self.strip_html("<h1><strong>Something</strong> else.</h1>")
+            == "<strong>Something</strong> else."
+        )
+        assert (
+            self.strip_html(
+                '<h1 id="moral"><strong>We believe</strong> that the internet should be public, open and accessible.</h1>'
+            )
+            == "<strong>We believe</strong> that the internet should be public, open and accessible."
+        )
+        assert (
+            self.strip_html(
+                '<h3><a href="http://www.firefox.com/" class="producttitle"><img src="../images/product-firefox-50.png" width="50" height="50" alt="" class="featured" style="display: block; margin-bottom: 30px;" /><strong>Firefox for Desktop</strong></a></h3>'
+            )
+            == "Firefox for Desktop"
+        )
 
     def test_extraction_tag_figcaption(self):
         """Check that we can extract figcaption"""
         h = html.htmlfile()
         # Example form http://www.w3schools.com/tags/tag_figcaption.asp
-        store = h.parsestring("""
+        store = h.parsestring(
+            """
                <figure>
                    <img src="img_pulpit.jpg" alt="The Pulpit Rock" width="304" height="228">
                    <figcaption>Fig1. - A view of the pulpit rock in Norway.</figcaption>
-               </figure>""")
+               </figure>"""
+        )
         print(store.units[0].source)
         assert len(store.units) == 2
         assert store.units[0].source == "The Pulpit Rock"
@@ -97,7 +142,8 @@ class TestHTMLExtraction:
         """Check that we can extract table related translatable: th, td and caption"""
         h = html.htmlfile()
         # Example form http://www.w3schools.com/tags/tag_caption.asp
-        store = h.parsestring("""
+        store = h.parsestring(
+            """
             <table>
                 <caption>Monthly savings</caption>
                 <tr>
@@ -108,7 +154,8 @@ class TestHTMLExtraction:
                     <td>January</td>
                     <td>$100</td>
                 </tr>
-            </table>""")
+            </table>"""
+        )
         print(store.units[0].source)
         assert len(store.units) == 5
         assert store.units[0].source == "Monthly savings"
@@ -121,42 +168,57 @@ class TestHTMLExtraction:
         """Check that we can extract title attribute"""
         h = html.htmlfile()
         # Example from http://www.netmechanic.com/news/vol6/html_no1.htm
-        store = h.parsestring("""
+        store = h.parsestring(
+            """
             <img src="cafeteria.jpg" height="200" width="200" alt="UAHC campers enjoy a meal in the camp cafeteria">
-        """)
+        """
+        )
         assert len(store.units) == 1
-        assert store.units[0].source == "UAHC campers enjoy a meal in the camp cafeteria"
+        assert (
+            store.units[0].source == "UAHC campers enjoy a meal in the camp cafeteria"
+        )
 
     def test_extraction_attr_title(self):
         """Check that we can extract title attribute"""
         h = html.htmlfile()
 
         # Example form http://www.w3schools.com/tags/att_global_title.asp
-        store = h.parsestring("""
+        store = h.parsestring(
+            """
             <p><abbr title="World Health Organization">WHO</abbr> was founded in 1948.</p>
-            <p title="Free Web tutorials">W3Schools.com</p>""")
+            <p title="Free Web tutorials">W3Schools.com</p>"""
+        )
         print(store.units[0].source)
         assert len(store.units) == 3
-        assert store.units[0].source == '<abbr title="World Health Organization">WHO</abbr> was founded in 1948.'
+        assert (
+            store.units[0].source
+            == '<abbr title="World Health Organization">WHO</abbr> was founded in 1948.'
+        )
         assert store.units[1].source == "Free Web tutorials"
         assert store.units[2].source == "W3Schools.com"
 
         # Example from http://www.netmechanic.com/news/vol6/html_no1.htm
-        store = h.parsestring("""
+        store = h.parsestring(
+            """
             <table width="100" border="2" title="Henry Jacobs Camp summer 2003 schedule">
-        """)
+        """
+        )
         assert len(store.units) == 1
         assert store.units[0].source == "Henry Jacobs Camp summer 2003 schedule"
 
-        store = h.parsestring("""
+        store = h.parsestring(
+            """
            <div><a href="page1.html" title="HS Jacobs - a UAHC camp in Utica, MS">Henry S. Jacobs Camp</a></div>
-        """)
+        """
+        )
         assert len(store.units) == 2
         assert store.units[0].source == "HS Jacobs - a UAHC camp in Utica, MS"
         assert store.units[1].source == "Henry S. Jacobs Camp"
 
-        store = h.parsestring("""
+        store = h.parsestring(
+            """
             <form name="application" title="Henry Jacobs camper application" method="  " action="  ">
-        """)
+        """
+        )
         assert len(store.units) == 1
         assert store.units[0].source == "Henry Jacobs camper application"
