@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
 # Copyright 2002-2011 Zuza Software Foundation
 # Copyright 2013 F Wolff
@@ -28,21 +26,21 @@ See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/command
 for examples and usage instructions.
 """
 
-import re
 import locale
+import re
 
-from translate.storage import factory
-from translate.storage.poheader import poheader
+from translate.lang import data
 from translate.misc import optrecurse
 from translate.misc.multistring import multistring
-from translate.lang import data
+from translate.storage import factory
+from translate.storage.poheader import poheader
 
 
-class GrepMatch(object):
+class GrepMatch:
     """Just a small data structure that represents a search match."""
 
     # INITIALIZERS #
-    def __init__(self, unit, part='target', part_n=0, start=0, end=0):
+    def __init__(self, unit, part="target", part_n=0, start=0, end=0):
         self.unit = unit
         self.part = part
         self.part_n = part_n
@@ -51,41 +49,45 @@ class GrepMatch(object):
 
     # ACCESSORS #
     def get_getter(self):
-        if self.part == 'target':
+        if self.part == "target":
             if self.unit.hasplural():
                 getter = lambda: self.unit.target.strings[self.part_n]
             else:
                 getter = lambda: self.unit.target
             return getter
-        elif self.part == 'source':
+        elif self.part == "source":
             if self.unit.hasplural():
                 getter = lambda: self.unit.source.strings[self.part_n]
             else:
                 getter = lambda: self.unit.source
             return getter
-        elif self.part == 'notes':
+        elif self.part == "notes":
 
             def getter():
                 return self.unit.getnotes()[self.part_n]
+
             return getter
-        elif self.part == 'locations':
+        elif self.part == "locations":
 
             def getter():
                 return self.unit.getlocations()[self.part_n]
+
             return getter
 
     def get_setter(self):
-        if self.part == 'target':
+        if self.part == "target":
             if self.unit.hasplural():
 
                 def setter(value):
                     strings = self.unit.target.strings
                     strings[self.part_n] = value
                     self.unit.target = strings
+
             else:
 
                 def setter(value):
                     self.unit.target = value
+
             return setter
 
     # SPECIAL METHODS #
@@ -95,8 +97,14 @@ class GrepMatch(object):
             start = 3
         if end > len(self.get_getter()()) - 3:
             end = len(self.get_getter()()) - 3
-        matchpart = self.get_getter()()[start-2:end+2]
-        return '<GrepMatch "%s" part=%s[%d] start=%d end=%d>' % (matchpart, self.part, self.part_n, self.start, self.end)
+        matchpart = self.get_getter()()[start - 2 : end + 2]
+        return '<GrepMatch "%s" part=%s[%d] start=%d end=%d>' % (
+            matchpart,
+            self.part,
+            self.part_n,
+            self.start,
+            self.end,
+        )
 
     def __repr__(self):
         return str(self)
@@ -104,7 +112,8 @@ class GrepMatch(object):
 
 def real_index(string, nfc_index):
     """Calculate the real index in the unnormalized string that corresponds to
-    the index nfc_index in the normalized string."""
+    the index nfc_index in the normalized string.
+    """
     length = nfc_index
     max_length = len(string)
     while len(data.normalize(string[:length])) <= nfc_index:
@@ -133,12 +142,20 @@ def find_matches(unit, part, strings, re_search):
 
 
 class GrepFilter:
-
-    def __init__(self, searchstring, searchparts, ignorecase=False, useregexp=False,
-            invertmatch=False, keeptranslations=False, accelchar=None, encoding='utf-8',
-            max_matches=0):
+    def __init__(
+        self,
+        searchstring,
+        searchparts,
+        ignorecase=False,
+        useregexp=False,
+        invertmatch=False,
+        keeptranslations=False,
+        accelchar=None,
+        encoding="utf-8",
+        max_matches=0,
+    ):
         """builds a checkfilter using the given checker"""
-        if isinstance(searchstring, unicode):
+        if isinstance(searchstring, str):
             self.searchstring = searchstring
         else:
             self.searchstring = searchstring.decode(encoding)
@@ -146,10 +163,10 @@ class GrepFilter:
         if searchparts:
             # For now we still support the old terminology, except for the old 'source'
             # which has a new meaning now.
-            self.search_source = ('source' in searchparts) or ('msgid' in searchparts)
-            self.search_target = ('target' in searchparts) or ('msgstr' in searchparts)
-            self.search_notes = ('notes' in searchparts) or ('comment' in searchparts)
-            self.search_locations = 'locations' in searchparts
+            self.search_source = ("source" in searchparts) or ("msgid" in searchparts)
+            self.search_target = ("target" in searchparts) or ("msgstr" in searchparts)
+            self.search_notes = ("notes" in searchparts) or ("comment" in searchparts)
+            self.search_locations = "locations" in searchparts
         else:
             self.search_source = True
             self.search_target = True
@@ -213,7 +230,7 @@ class GrepFilter:
             if self.matches(unit.getnotes()):
                 return True
         if self.search_locations:
-            if self.matches(u" ".join(unit.getlocations())):
+            if self.matches(" ".join(unit.getlocations())):
                 return True
         return False
 
@@ -241,7 +258,7 @@ class GrepFilter:
             flags |= re.IGNORECASE
         if not self.useregexp:
             searchstring = re.escape(searchstring)
-        self.re_search = re.compile(u'(%s)' % (searchstring), flags)
+        self.re_search = re.compile("(%s)" % (searchstring), flags)
 
         matches = []
         indexes = []
@@ -254,18 +271,22 @@ class GrepFilter:
                     targets = unit.target.strings
                 else:
                     targets = [unit.target]
-                matches.extend(find_matches(unit, 'target', targets, self.re_search))
+                matches.extend(find_matches(unit, "target", targets, self.re_search))
             if self.search_source:
                 if unit.hasplural():
                     sources = unit.source.strings
                 else:
                     sources = [unit.source]
-                matches.extend(find_matches(unit, 'source', sources, self.re_search))
+                matches.extend(find_matches(unit, "source", sources, self.re_search))
             if self.search_notes:
-                matches.extend(find_matches(unit, 'notes', unit.getnotes(), self.re_search))
+                matches.extend(
+                    find_matches(unit, "notes", unit.getnotes(), self.re_search)
+                )
 
             if self.search_locations:
-                matches.extend(find_matches(unit, 'locations', unit.getlocations(), self.re_search))
+                matches.extend(
+                    find_matches(unit, "locations", unit.getlocations(), self.re_search)
+                )
 
             # A search for a single letter or an all-inclusive regular
             # expression could give enough results to cause performance
@@ -285,7 +306,9 @@ class GrepOptionParser(optrecurse.RecursiveOptionParser):
 
     def parse_args(self, args=None, values=None):
         """parses the command line options, handling implicit input/output args"""
-        (options, args) = optrecurse.optparse.OptionParser.parse_args(self, args, values)
+        (options, args) = optrecurse.optparse.OptionParser.parse_args(
+            self, args, values
+        )
         # some intelligence as to what reasonable people might give on the command line
         if args:
             options.searchstring = args[0]
@@ -303,7 +326,9 @@ class GrepOptionParser(optrecurse.RecursiveOptionParser):
             options.output = args[-1]
             args = args[:-1]
         if args:
-            self.error("You have used an invalid combination of --input, --output and freestanding args")
+            self.error(
+                "You have used an invalid combination of --input, --output and freestanding args"
+            )
         if isinstance(options.input, list) and len(options.input) == 1:
             options.input = options.input[0]
         return (options, args)
@@ -311,23 +336,25 @@ class GrepOptionParser(optrecurse.RecursiveOptionParser):
     def set_usage(self, usage=None):
         """sets the usage string - if usage not given, uses getusagestring for each option"""
         if usage is None:
-            self.usage = "%prog searchstring " + " ".join([self.getusagestring(option) for option in self.option_list])
+            self.usage = "%prog searchstring " + " ".join(
+                self.getusagestring(option) for option in self.option_list
+            )
         else:
-            super(GrepOptionParser, self).set_usage(usage)
+            super().set_usage(usage)
 
     def run(self):
         """parses the arguments, and runs recursiveprocess with the resulting options"""
         (options, args) = self.parse_args()
-        options.inputformats = self.inputformats
-        options.outputoptions = self.outputoptions
-        options.checkfilter = GrepFilter(options.searchstring,
-                                         options.searchparts,
-                                         options.ignorecase,
-                                         options.useregexp,
-                                         options.invertmatch,
-                                         options.keeptranslations,
-                                         options.accelchar,
-                                         locale.getpreferredencoding())
+        options.checkfilter = GrepFilter(
+            options.searchstring,
+            options.searchparts,
+            options.ignorecase,
+            options.useregexp,
+            options.invertmatch,
+            options.keeptranslations,
+            options.accelchar,
+            locale.getpreferredencoding(),
+        )
         self.recursiveprocess(options)
 
 
@@ -337,33 +364,85 @@ def rungrep(inputfile, outputfile, templatefile, checkfilter):
     tofile = checkfilter.filterfile(fromfile)
     if tofile.isempty():
         return False
-    outputfile.write(str(tofile))
+    tofile.serialize(outputfile)
     return True
 
 
 def cmdlineparser():
-    formats = {"po": ("po", rungrep), "pot": ("pot", rungrep),
-            "mo": ("mo", rungrep), "gmo": ("gmo", rungrep),
-            "tmx": ("tmx", rungrep),
-            "xliff": ("xliff", rungrep), "xlf": ("xlf", rungrep), "xlff": ("xlff", rungrep),
-            None: ("po", rungrep)}
+    formats = {
+        "po": ("po", rungrep),
+        "pot": ("pot", rungrep),
+        "mo": ("mo", rungrep),
+        "gmo": ("gmo", rungrep),
+        "tmx": ("tmx", rungrep),
+        "xliff": ("xliff", rungrep),
+        "xlf": ("xlf", rungrep),
+        "xlff": ("xlff", rungrep),
+        None: ("po", rungrep),
+    }
     parser = GrepOptionParser(formats)
-    parser.add_option("", "--search", dest="searchparts",
-        action="append", type="choice", choices=["source", "target", "notes", "locations", "msgid", "msgstr", "comment"],
-        metavar="SEARCHPARTS", help="searches the given parts (source, target, notes and locations)")
-    parser.add_option("-I", "--ignore-case", dest="ignorecase",
-        action="store_true", default=False, help="ignore case distinctions")
-    parser.add_option("-e", "--regexp", dest="useregexp",
-        action="store_true", default=False, help="use regular expression matching")
-    parser.add_option("-v", "--invert-match", dest="invertmatch",
-        action="store_true", default=False, help="select non-matching lines")
-    parser.add_option("", "--accelerator", dest="accelchar",
-        action="store", type="choice", choices=["&", "_", "~"],
-        metavar="ACCELERATOR", help="ignores the given accelerator when matching")
-    parser.add_option("-k", "--keep-translations", dest="keeptranslations",
-        action="store_true", default=False, help="always extract units with translations")
+    parser.add_option(
+        "",
+        "--search",
+        dest="searchparts",
+        action="append",
+        type="choice",
+        choices=[
+            "source",
+            "target",
+            "notes",
+            "locations",
+            "msgid",
+            "msgstr",
+            "comment",
+        ],
+        metavar="SEARCHPARTS",
+        help="searches the given parts (source, target, notes and locations)",
+    )
+    parser.add_option(
+        "-I",
+        "--ignore-case",
+        dest="ignorecase",
+        action="store_true",
+        default=False,
+        help="ignore case distinctions",
+    )
+    parser.add_option(
+        "-e",
+        "--regexp",
+        dest="useregexp",
+        action="store_true",
+        default=False,
+        help="use regular expression matching",
+    )
+    parser.add_option(
+        "-v",
+        "--invert-match",
+        dest="invertmatch",
+        action="store_true",
+        default=False,
+        help="select non-matching lines",
+    )
+    parser.add_option(
+        "",
+        "--accelerator",
+        dest="accelchar",
+        action="store",
+        type="choice",
+        choices=["&", "_", "~"],
+        metavar="ACCELERATOR",
+        help="ignores the given accelerator when matching",
+    )
+    parser.add_option(
+        "-k",
+        "--keep-translations",
+        dest="keeptranslations",
+        action="store_true",
+        default=False,
+        help="always extract units with translations",
+    )
     parser.set_usage()
-    parser.passthrough.append('checkfilter')
+    parser.passthrough.append("checkfilter")
     parser.description = __doc__
     return parser
 
@@ -373,5 +452,5 @@ def main():
     parser.run()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
